/*
 * Copyright (c) 2019 Marc Reilly
 *
 * SPDX-License-Identifier: Apache-2.0
 */
#ifndef ST7305_DISPLAY_DRIVER_H__
#define ST7305_DISPLAY_DRIVER_H__

#include <zephyr/kernel.h>

#define ST7305_CMD_NOP				0x00
#define ST7305_CMD_SW_RESET			0x01

#define ST7305_CMD_NVMCTRL			0xd6
#define ST7305_CMD_BOOSTER_EN			0xd1
#define ST7305_CMD_GVCTRL			0xc0
#define ST7305_CMD_VSHP			0xc1
#define ST7305_CMD_VSLP			0xc2
#define ST7305_CMD_VSHN			0xc4
#define ST7305_CMD_VSLN			0xc5
#define ST7305_CMD_FRCTL			0xb2
#define ST7305_CMD_HPMCTL			0xb3
#define ST7305_CMD_LPMCTL			0xb4

#define ST7305_CMD_SRCEQ			0xb7
#define ST7305_CMD_GTLINE			0xb0

#define ST7305_CMD_OSC 			0xd8
#define ST7305_CMD_SRCV 			0xc9
#define ST7305_CMD_MADCTL			0x36
#define ST7305_CMD_DFS			    0x3a
#define ST7305_CMD_GAMSET			0xb9
#define ST7305_CMD_PSET   			0xb8
#define ST7305_CMD_CASET			0x2a
#define ST7305_CMD_RASET			0x2b

#define ST7305_CMD_TEOFF			0x34
#define ST7305_CMD_TESET			0x35

#define ST7305_CMD_ENPWD			0xd0

#define ST7305_CMD_LPMON			0x39
#define ST7305_CMD_DISP_ON			0x29

#define ST7305_CMD_SLEEP_IN			0x10
#define ST7305_CMD_SLEEP_OUT			0x11
#define ST7305_CMD_INV_OFF			0x20
#define ST7305_CMD_INV_ON			0x21

#define ST7305_CMD_DISP_OFF			0x28

#define ST7305_CMD_LOWPWR			0xc7
#define ST7305_SW_RESET             0x01

#define ST7305_CMD_RAMWR			0x2c
#define ST7305_CMD_CONT			0x3c


#define ST7305_MADCTL_MY_TOP_TO_BOTTOM		0x00
#define ST7305_MADCTL_MY_BOTTOM_TO_TOP		0x80
#define ST7305_MADCTL_MX_LEFT_TO_RIGHT		0x00
#define ST7305_MADCTL_MX_RIGHT_TO_LEFT		0x40
#define ST7305_MADCTL_MV_REVERSE_MODE		0x20
#define ST7305_MADCTL_MV_NORMAL_MODE		0x00


#define ST7305_MADCTL_ML			0x10
#define ST7305_MADCTL_RBG			0x00
#define ST7305_MADCTL_BGR			0x08
#define ST7305_MADCTL_MH_LEFT_TO_RIGHT		0x00
#define ST7305_MADCTL_MH_RIGHT_TO_LEFT		0x04

#define ST7305_CMD_GATE_TIMING		0x62


#define ST7305_CMD_COLMOD			0x3a
#define ST7305_COLMOD_RGB_65K			(0x5 << 4)
#define ST7305_COLMOD_RGB_262K			(0x6 << 4)
#define ST7305_COLMOD_FMT_12bit		(3)
#define ST7305_COLMOD_FMT_16bit		(5)
#define ST7305_COLMOD_FMT_18bit		(6)

#define ST7305_CMD_PORCTRL			0xb2
#define ST7305_CMD_GCTRL			0xb7
#define ST7305_CMD_CLEAR_RAM			0xbb


#define COLUMN_START  0x13  // Per datasheet, valid range starts at 0x13
#define COLUMN_END    0x28  // Valid range ends at 0x28
#define ROW_START     0x00  // Minimum row address
#define ROW_END       0x9F  // Maximum row address

#endif